
-- PostgreSQL specific Cofax database creation script.
-- Procedures were removed and placed in the 
-- 		'goon-postgresql-procedures.sql' file for easier maintenance.
--
-- Indexes and Constraints were removed and placed in the 
--		'goon-postgresql-index_constraint.sql' file for easier maintenance.







--DROP all tables prior to creating them: (remember to drop views, indexes, etc
--		which rely on the tables, before deleting the tables!!!

DROP TABLE tblToolsPublicationConfig;
DROP TABLE tblToolsPackageTags;
DROP TABLE tblSections;
DROP TABLE tblRelatedLinks;
DROP TABLE tblPublications;
DROP TABLE tblPermUsers;
DROP TABLE tblPermUserGroup;
DROP TABLE tblPermSavedSearches;
DROP TABLE tblPermModes;
DROP TABLE tblPermGroupType;
DROP TABLE tblPermGroups;
DROP TABLE tblPermGroupPublication;
DROP TABLE tblPackageTags;
DROP TABLE tblMultimedia;
DROP TABLE tblMonthDay;
DROP TABLE tblArticleTypes;
DROP TABLE tblArticleTypeCategories;
DROP TABLE tblArticles;
DROP TABLE tblArticlePreload;
DROP TABLE tblArticleOrder;
DROP TABLE tblAdsTags;





--BEGIN TRANSACTION CREATE_TABLES






-- now that the database is clean, create the tables



CREATE TABLE tblAdsTags (
	ID SERIAL NOT NULL ,
	PUBNAME varchar(50) NOT NULL ,
	SECTIONNAME varchar(50) NOT NULL ,
	ADSPUBLICATION varchar(50) NOT NULL ,
	ADSSECTION varchar(50) NOT NULL ,
	SHOWADSBANNER varchar(500) NOT NULL ,
	SHOWADSBANNERTOP varchar(500) NOT NULL ,
	SHOWADSBANNERBOTTOM varchar(500) NOT NULL ,
	SHOWADSBANNERMIDDLE varchar(500) NOT NULL ,
	SHOWADSBUTTON varchar(500) NOT NULL ,
	SHOWADSBUTTONGROUPA varchar(500) NOT NULL ,
	SHOWADSBUTTONGROUPB varchar(500) NOT NULL ,
	SHOWADSBUTTONGROUPC varchar(500) NOT NULL ,
	SHOWADSBUTTONGROUPD varchar(500) NOT NULL ,
	SHOWADSBUTTONGROUPE varchar(500) NOT NULL ,
	updateDate timestamp NOT NULL 
) 
;

CREATE TABLE tblArticleOrder (
	itemID int4 NOT NULL ,
	mappingCode int4 NOT NULL ,
	rank int4 NOT NULL ,
	timeStart timestamp NULL ,
	timeEnd timestamp NULL ,
	mappingUpdateDate timestamp NULL ,
	pubName varchar(50) NULL ,
	section varchar(50) NULL ,
	pubDate timestamp NULL 
) 
;

CREATE TABLE tblArticlePreload (
	itemID int4 NOT NULL ,
	mappingCode int4 NOT NULL ,
	shortTime char (20) NULL ,
	dayOfWeek varchar(15) NULL ,
	virtualFolder varchar(162) NULL ,
	pubSectionDesc varchar(255) NULL ,
	pubYear varchar(4) NULL ,
	pubMonth varchar(2) NULL ,
	pubDay varchar(2) NULL ,
	dateFolder varchar(10) NULL ,
	pubDateLong varchar(32) NULL ,
	fullLink varchar(255) NULL ,
	articleLeadIn varchar(100) NULL ,
	sigImage varchar(255) NULL ,
	sigImageCaption varchar(50) NULL ,
	listImage varchar(50) NULL ,
	listImageCaption varchar(500) NULL ,
	articleImage varchar(50) NULL ,
	articleImageCaption varchar(500) NULL ,
	relatedLinksCount int4 NULL ,
	sectionName varchar(100) NULL ,
	sectionDesc varchar(255) NULL ,
	sigDir varchar(255) NULL ,
	sectionImage varchar(255) NULL ,
	sectionType int4 NULL ,
	pubDesc varchar(1000) NULL ,
	orderingRank int4 NULL ,
	hostName varchar(50) NULL 
) 
;

CREATE TABLE tblArticles (
	pubName varchar(50) NOT NULL ,
	pubDate timestamp NOT NULL ,
	memo varchar(1000) NOT NULL ,
	correction varchar(1000) NOT NULL ,
	headline varchar(1000) NOT NULL ,
	lead varchar(2000) NOT NULL ,
	dateline varchar(100) NOT NULL ,
	keywords varchar(1000) NOT NULL ,
	pubStart timestamp NULL ,
	pubEnd timestamp NULL ,
	pubData varchar(1000) NOT NULL ,
	updateDate timestamp NULL ,
	versionNum int4 NOT NULL ,
	docType int4 NOT NULL ,
	shortHeadline varchar(250) NOT NULL ,
	byline varchar(255) NOT NULL ,
	data varchar(1000) NOT NULL ,
	body text NOT NULL ,
	section varchar(25) NOT NULL ,
	disableArticle int4 NOT NULL ,
	pubRank varchar(25) NULL ,
	headline2 varchar(1000) NOT NULL ,
	bycredit varchar(255) NOT NULL ,
	webLead varchar(2000) NOT NULL ,
	docID SERIAL NOT NULL ,
	fileName varchar(50) NOT NULL ,
	approved varchar(25) NOT NULL ,
	disableIndex int4 NOT NULL ,
	itemID int4 NOT NULL ,
	articleTypeID int4 NULL ,
	webHeadline varchar(255) NULL ,
	leadIn varchar(255) NULL ,
	customURL varchar(255) NULL 
) 
;

CREATE TABLE tblArticleTypeCategories (
	articleTypeCategoryID SERIAL NOT NULL ,
	articleTypeCategory varchar(25) NOT NULL 
) 
;

CREATE TABLE tblArticleTypes (
	articleTypeID SERIAL NOT NULL ,
	pubName varchar(50) NOT NULL ,
	articleType varchar(50) NOT NULL ,
	articleTypeName varchar(50) NOT NULL ,
	articleTypeDesc varchar(100) NOT NULL ,
	articleTypeMappingCode int4 NULL ,
	articleTypeImage varchar(255) NOT NULL ,
	articleTypeByline varchar(50) NOT NULL ,
	articleTypeTitle varchar(50) NOT NULL ,
	articleTypeCategoryID int4 NULL ,
	articleTypeCategory varchar(50) NULL ,
	articleTypeLeadIn varchar(100) NOT NULL ,
	articleTypeEmail varchar(100) NOT NULL ,
	articleTypeBio text NOT NULL ,
	articleTypeShirtTail text NOT NULL ,
	articleTypeDisplayOnIndex int4 NOT NULL ,
	disableArticleType int4 NOT NULL ,
	articleTypeUpdateDate timestamp NULL 
) 
;

CREATE TABLE tblMonthDay (
	monthDayID SERIAL NOT NULL ,
	monthNameShort varchar(50) NOT NULL ,
	monthID varchar(50) NOT NULL ,
	dayNameShort varchar(50) NOT NULL ,
	dayName varchar(50) NOT NULL ,
	dayID varchar(50) NOT NULL ,
	numberDayOfMonth varchar(50) NOT NULL 
) 
;

CREATE TABLE tblMultimedia (
	multimediaID SERIAL NOT NULL ,
	type varchar(50) NOT NULL ,
	itemID int4 NOT NULL ,
	itemName varchar(50) NOT NULL ,
	caption varchar(500) NOT NULL ,
	mimeType varchar(50) NOT NULL ,
	rank int4 NOT NULL ,
	credit varchar(100) NOT NULL ,
	multimediaUpdateDate timestamp NULL 
) 
;

CREATE TABLE tblPackageTags (
	tag_name char (50) NOT NULL ,
	tag_value varchar (2500) NOT NULL ,
	create_date timestamp NOT NULL ,
	modified_date timestamp NOT NULL ,
	returnError int4 NOT NULL 
) 
;

CREATE TABLE tblPermGroupPublication (
	groupID int4 NOT NULL ,
	pubID int4 NOT NULL 
) 
;

CREATE TABLE tblPermGroups (
	groupID SERIAL NOT NULL ,
	groupName varchar (50) NOT NULL ,
	groupDesc varchar (100) NOT NULL ,
	groupType int4 NOT NULL 
) 
;

CREATE TABLE tblPermGroupType (
	groupTypeName varchar (50) NOT NULL ,
	groupTypeDesc varchar (200) NULL ,
	groupTypeID SERIAL NOT NULL 
) 
;

CREATE TABLE tblPermModes (
	permModesID SERIAL NOT NULL ,
	modes varchar (50) NOT NULL ,
	type int4 NOT NULL 
) 
;

CREATE TABLE tblPermSavedSearches (
	userID int4 NOT NULL ,
	search text NOT NULL ,
	searchName varchar (100) NOT NULL 
) 
;

CREATE TABLE tblPermUserGroup (
	userID int4 NOT NULL ,
	groupID int4 NOT NULL 
) 
;

CREATE TABLE tblPermUsers (
	userID SERIAL NOT NULL ,
	userName varchar (20) NOT NULL ,
	userPassword varchar (20) NOT NULL ,
	lastName varchar (50) NOT NULL ,
	firstName varchar (50) NOT NULL ,
	homePub int4 NOT NULL ,
	email varchar (100) NULL ,
	workPhone varchar (50) NULL ,
	cellPhone varchar (50) NULL ,
	pager varchar (50) NULL ,
	notes varchar (50) NULL 
) 
;

CREATE TABLE tblPublications (
	publication varchar(50) NOT NULL ,
	pubName varchar(50) NOT NULL ,
	pubDesc varchar(1000) NOT NULL ,
	tagLine varchar(500) NOT NULL ,
	homePage varchar(100) NOT NULL ,
	icon char (100) NOT NULL ,
	iconWidth int4 NOT NULL ,
	iconHeight int4 NOT NULL ,
	javaScript varchar(1000) NOT NULL ,
	pubID SERIAL NOT NULL ,
	rolloverTime int4 NOT NULL ,
	hostName varchar(50) NOT NULL ,
	defaultSection varchar(100) NOT NULL ,
	defaultSectionWithDate int4 NOT NULL ,
	pubUpdateDate timestamp NULL 
) 
;

CREATE TABLE tblRelatedLinks (
	itemID int4 NOT NULL ,
	link varchar(255) NOT NULL ,
	rank int4 NOT NULL ,
	text varchar(500) NULL ,
	linkUpdateDate timestamp NULL 
) 
;

CREATE TABLE tblSections (
	pubName varchar(50) NOT NULL ,
	section varchar(50) NOT NULL ,
	sectionDesc varchar(255) NULL ,
	image varchar(255) NULL ,
	orderFile varchar(255) NULL ,
	sigDir varchar(255) NULL ,
	sectionName varchar(100) NOT NULL ,
	mappingCode SERIAL NOT NULL ,
	subMapOf int4 NOT NULL ,
	sectionType int4 NOT NULL ,
	javaScript varchar(100) NULL ,
	include varchar(5000) NULL ,
	promo varchar(5000) NULL ,
	rank int4 NOT NULL ,
	url varchar(255) NOT NULL ,
	displayOnIndex int4 NOT NULL ,
	sectionUpdateDate timestamp NULL 
)
;

CREATE TABLE tblToolsPackageTags (
	tag_name varchar (50) NOT NULL ,
	tag_value text NOT NULL ,
	create_date timestamp NOT NULL ,
	modified_date timestamp NOT NULL ,
	tagID int4 NOT NULL ,
	cache int4 NOT NULL 
) 
;

CREATE TABLE tblToolsPublicationConfig (
	pubID int4 NOT NULL ,
	domainName varchar (100) NOT NULL ,
	testFTPServer text NOT NULL ,
	testFTPLogin varchar (100) NOT NULL ,
	testFTPPassword varchar (100) NOT NULL ,
	testTemplateFolder varchar (100) NOT NULL ,
	testImagesFolder varchar (100) NOT NULL ,
	liveFTPServer text NOT NULL ,
	liveFTPLogin varchar (100) NOT NULL ,
	liveFTPPassword varchar (100) NOT NULL ,
	liveTemplateFolder varchar (100) NOT NULL ,
	liveImagesFolder varchar (100) NOT NULL ,
	liveImagesServer text NOT NULL ,
	importFTPServer text NOT NULL ,
	importFTPLogin varchar (100) NOT NULL ,
	importFTPPassword varchar (100) NOT NULL ,
	importFTPFilePath varchar (100) NOT NULL ,
	importFTPFileContents varchar (100) NOT NULL ,
	mainCofaxServer varchar (100) NOT NULL ,
	imagesURLPrefix varchar (100) NOT NULL ,
	cacheServers text NOT NULL 
) 
;




--COMMIT TRANSACTION CREATE_TABLES